@import "compass/css3/images";

images {
    vendor-image-url: image-url("vendor_1x1.png"); 
    app-image-url: image-url("@images/image.png");
    width-app: image-width("@images/image.png");
    width-vendor: image-width("vendor_image.png");
    image-inline: inline-image("@images/1x1.png");
    vendor-generated-image-busted: generated-image-url("1x1.png", true);
    vendor-generated-image: generated-image-url("1x1.png", false);
    generated-image-busted: generated-image-url("@1x1.png", true);
    generated-image: generated-image-url("@1x1.png", false); 
}
